@@ -11,7 +11,6 @@ import (
 	"time"
 
 	"github.com/davecgh/go-spew/spew"
-	"k8s.io/klog"
 	"github.com/google/uuid"
 	apiextv1beta1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
 	apiextclientv1 "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset/typed/apiextensions/v1beta1"
@@ -28,11 +27,11 @@ import (
 	"k8s.io/client-go/rest"
 	ktesting "k8s.io/client-go/testing"
 	"k8s.io/client-go/util/workqueue"
+	"k8s.io/klog"
 
 	configv1 "github.com/openshift/api/config/v1"
 	clientset "github.com/openshift/client-go/config/clientset/versioned"
 	"github.com/openshift/client-go/config/clientset/versioned/fake"
-
 	"github.com/openshift/cluster-version-operator/pkg/payload"
 )
 
@@ -43,15 +42,35 @@ var (
 	defaultCompletionTime = metav1.Time{Time: time.Unix(2, 0)}
 )
 
+type clientProxyLister struct {
+	client clientset.Interface
+}
+
+func (c *clientProxyLister) Get(name string) (*configv1.Proxy, error) {
+	return c.client.ConfigV1().Proxies().Get(name, metav1.GetOptions{})
+}
+
+func (c *clientProxyLister) List(selector labels.Selector) (ret []*configv1.Proxy, err error) {
+	list, err := c.client.ConfigV1().Proxies().List(metav1.ListOptions{LabelSelector: selector.String()})
+	if err != nil {
+		return nil, err
+	}
+	var items []*configv1.Proxy
+	for i := range list.Items {
+		items = append(items, &list.Items[i])
+	}
+	return items, nil
+}
+
 type clientCVLister struct {
 	client clientset.Interface
 }
 
 func (c *clientCVLister) Get(name string) (*configv1.ClusterVersion, error) {
-	return c.client.Config().ClusterVersions().Get(name, metav1.GetOptions{})
+	return c.client.ConfigV1().ClusterVersions().Get(name, metav1.GetOptions{})
 }
 func (c *clientCVLister) List(selector labels.Selector) (ret []*configv1.ClusterVersion, err error) {
-	list, err := c.client.Config().ClusterVersions().List(metav1.ListOptions{LabelSelector: selector.String()})
+	list, err := c.client.ConfigV1().ClusterVersions().List(metav1.ListOptions{LabelSelector: selector.String()})
 	if err != nil {
 		return nil, err
 	}
@@ -62,15 +81,32 @@ func (c *clientCVLister) List(selector labels.Selector) (ret []*configv1.Cluster
 	return items, nil
 }
 
+type proxyLister struct {
+	Err   error
+	Items []*configv1.Proxy
+}
+
+func (r *proxyLister) List(selector labels.Selector) (ret []*configv1.Proxy, err error) {
+	return r.Items, r.Err
+}
+func (r *proxyLister) Get(name string) (*configv1.Proxy, error) {
+	for _, s := range r.Items {
+		if s.Name == name {
+			return s, nil
+		}
+	}
+	return nil, errors.NewNotFound(schema.GroupResource{}, name)
+}
+
 type clientCOLister struct {
 	client clientset.Interface
 }
 
 func (c *clientCOLister) Get(name string) (*configv1.ClusterOperator, error) {
-	return c.client.Config().ClusterOperators().Get(name, metav1.GetOptions{})
+	return c.client.ConfigV1().ClusterOperators().Get(name, metav1.GetOptions{})
 }
 func (c *clientCOLister) List(selector labels.Selector) (ret []*configv1.ClusterOperator, err error) {
-	list, err := c.client.Config().ClusterOperators().List(metav1.ListOptions{LabelSelector: selector.String()})
+	list, err := c.client.ConfigV1().ClusterOperators().List(metav1.ListOptions{LabelSelector: selector.String()})
 	if err != nil {
 		return nil, err
 	}
@@ -116,16 +152,16 @@ func (r *coLister) Get(name string) (*configv1.ClusterOperator, error) {
 	return nil, errors.NewNotFound(schema.GroupResource{}, name)
 }
 
-type cmLister struct {
+type cmConfigLister struct {
 	Err   error
 	Items []*corev1.ConfigMap
 }
 
-func (l *cmLister) List(selector labels.Selector) ([]*corev1.ConfigMap, error) {
+func (l *cmConfigLister) List(selector labels.Selector) ([]*corev1.ConfigMap, error) {
 	return l.Items, l.Err
 }
 
-func (l *cmLister) Get(name string) (*corev1.ConfigMap, error) {
+func (l *cmConfigLister) Get(name string) (*corev1.ConfigMap, error) {
 	if l.Err != nil {
 		return nil, l.Err
 	}
@@ -1982,6 +2018,7 @@ func TestOperator_sync(t *testing.T) {
 			if tt.init != nil {
 				tt.init(optr)
 			}
+			optr.proxyLister = &clientProxyLister{client: optr.client}
 			optr.cvLister = &clientCVLister{client: optr.client}
 			optr.coLister = &clientCOLister{client: optr.client}
 			if optr.configSync == nil {
@@ -2355,6 +2392,7 @@ func TestOperator_availableUpdatesSync(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			optr := tt.optr
 			optr.queue = workqueue.NewRateLimitingQueue(workqueue.DefaultControllerRateLimiter())
+			optr.proxyLister = &clientProxyLister{client: optr.client}
 			optr.coLister = &clientCOLister{client: optr.client}
 			optr.cvLister = &clientCVLister{client: optr.client}
 
